# Repository for Terraform resources to create a new OWL infrastructure

## Requirements

- Terraform v1.6 or higher [Download here](https://developer.hashicorp.com/terraform/install?product_intent=terraform)
- Azure CLI [Download here](https://learn.microsoft.com/en-us/cli/azure/install-azure-cli-windows?tabs=azure-cli#install-or-update)
- hashicorp/azurerm ~>3.79.0 (will be downloaded automatically)
- Access to an Azure subscription with owner rights in a resource group (code changes needed)
- Access to an Azure subscription with admin rights (needed for providing access to storage account)

## Azure setup

1. Access Azure in your CLI with ```az login```
2. List all subscriptions ```az account list```
3. Set the correct subscription as your one in use ```az account set -s SUBSCRIPTION_ID```

## Basic terraform commands

1. Download terraform from this site https://developer.hashicorp.com/terraform/install?product_intent=terraform

2. Make terraform available through the Path variable (if you are using Windows)

3. Initialize terraform

First use ```terraform init``` to download the required providers and setup the modules of your repository.

Then, you have the option to start by ```terraform plan``` which is basically a dry-run against your cloud environment. This will check the current state of your cloud environment, compare it with the required resources you defined in the modules and then show the diff between them. I've prepared a ```fellowmind.tfvars``` file for the Fellowmind tenant.
You can use this files for skipping the need of defining variables during the ```terraform plan``` step by providing the arguments ```-var-file="fellowmind.tfvars"```.

The third step is to apply the changes. Therefore use ```terraform apply -var-file="fellowmind.tfvars" -parallelism=1```.
This step will take a while because it creates your whole infrastructure in Azure.

## Modules

This repository consists of 5 modules which can be executed separately if needed.

### ACR

The Azure Container Registry will store the container images used by Kubernetes. It's configured so the AKS can already access its contents.

### AKS

The Azure Kubernetes Service is the heart of this whole setup and will be used to run all OWL components.

### Public IP

This public ip address will be used for the traefik ingress to allow access to the whole Kubernetes cluster.

### Storage account

This storage account will be used for the picutures used by OWL. 

### Storage account state

This special storage account should be used to save the central state-file of the deployed versions of OWL. This service account will be accessible only by you. Therefore it will be set to private and you will be given contributor access (that's the reason for the need of elevated rights in Azure during the setup process)
