terraform {
  required_version = ">= 1.6.0"
  backend "local" {}

  # todo: change with local after testing
  #backend "azurerm" {
  #    storage_account_name = "owlstblobowliac"
  #    container_name       = "terraformstate"
  #    key                  = "owllive.terraform.tfstate"
  #    use_azuread_auth     = true
  #  }

  required_providers {
    azurerm = {
      source  = "hashicorp/azurerm"
      version = "~>3.79.0"
    }
  }

}

provider "azurerm" {
  features {}

  tenant_id       = var.tenant_id
  subscription_id = var.subscription_id
}

resource "random_integer" "rand_num" {
  min = 1
  max = 5000
}

# Parent resource group
resource "azurerm_resource_group" "rg-owllive" {
  name     = "${var.prefix}-rg-${var.resource_group_name}-${var.environment}"
  location = var.resource_group_location

  tags = {
    environment = var.environment
  }
}

# Modules

module "public_ip" {
  source                  = "./modules/public_ip"
  resource_group_name     = azurerm_resource_group.rg-owllive.name
  resource_group_location = azurerm_resource_group.rg-owllive.location
  environment             = var.environment
  prefix                  = var.prefix
  unique_suffix           = random_integer.rand_num.result
}

module "storage" {
  source                  = "./modules/storage"
  resource_group_name     = azurerm_resource_group.rg-owllive.name
  resource_group_location = azurerm_resource_group.rg-owllive.location
  environment             = var.environment
  prefix                  = var.prefix
  unique_suffix           = random_integer.rand_num.result
}

module "acr" {
  source                  = "./modules/acr"
  resource_group_name     = azurerm_resource_group.rg-owllive.name
  resource_group_location = azurerm_resource_group.rg-owllive.location
  environment             = var.environment
  prefix                  = var.prefix
  unique_suffix           = random_integer.rand_num.result
}

module "aks" {
  source                  = "./modules/aks"
  resource_group_name     = azurerm_resource_group.rg-owllive.name
  resource_group_location = azurerm_resource_group.rg-owllive.location
  environment             = var.environment
  prefix                  = var.prefix
  unique_suffix           = random_integer.rand_num.result
  acr_id                  = module.acr.id
}