terraform {
  required_providers {
    azurerm = {
      source  = "hashicorp/azurerm"
      version = ">=3.79.0"
    }
  }
}

provider "azurerm" {
  features {

  }
}

locals {
  aks_name = "${var.prefix}-aks-owllive-${var.environment}-${var.unique_suffix}"
}

resource "azurerm_kubernetes_cluster" "aks_owllive" {
  name                   = local.aks_name
  location               = var.resource_group_location
  resource_group_name    = var.resource_group_name
  dns_prefix             = "${local.aks_name}-dns"
  sku_tier               = "Free"
  local_account_disabled = false

  default_node_pool {
    name       = "defaultpool"
    node_count = 2
    vm_size    = "Standard_D2_v2"
    type       = "VirtualMachineScaleSets"
  }

  identity {
    type = "SystemAssigned"
  }

  tags = {
    Environment = var.environment
  }
}

# give AKS access to ACR for pulling containers

resource "azurerm_role_assignment" "aks_owllive_acr_role" {
  principal_id                     = azurerm_kubernetes_cluster.aks_owllive.kubelet_identity[0].object_id
  role_definition_name             = "AcrPull"
  scope                            = var.acr_id
  skip_service_principal_aad_check = true
}

resource "azurerm_kubernetes_cluster_node_pool" "productive_pool" {
  name                  = "productive"
  kubernetes_cluster_id = azurerm_kubernetes_cluster.aks_owllive.id
  vm_size               = "Standard_DS2_v2"
  node_count            = 6

  enable_auto_scaling = true
  min_count = 6
  max_count = 12

  tags = {
    Environment = "Prod"
  }
}

resource "azurerm_kubernetes_cluster_node_pool" "development_pool" {
  name                  = "development"
  kubernetes_cluster_id = azurerm_kubernetes_cluster.aks_owllive.id
  vm_size               = "Standard_DS2_v2"
  node_count            = 6

  enable_auto_scaling = true
  min_count = 6
  max_count = 6

  tags = {
    Environment = "Development"
  }
}
