terraform {
  required_version = ">= 1.6.0"
  backend "local" {}
  required_providers {
    azurerm = {
      source  = "hashicorp/azurerm"
      version = "3.75.0"
    }
  }
}

provider "azurerm" {
  features {}
}

data "azurerm_client_config" "current" {}

resource "azurerm_resource_group" "owl_iac_group" {
  name     = "rg-owl-iac"
  location = "westeurope"
}

resource "azurerm_storage_account" "owl_iac_storage" {
  name                      = "owlstblobowliac"
  resource_group_name       = azurerm_resource_group.owl_iac_group.name
  location                  = azurerm_resource_group.owl_iac_group.location
  account_kind              = "StorageV2"
  account_tier              = "Standard"
  account_replication_type  = "LRS"
  shared_access_key_enabled = true
  enable_https_traffic_only = true
  min_tls_version           = "TLS1_2"
  is_hns_enabled            = false
  blob_properties {
    change_feed_enabled = false
    versioning_enabled  = true
  }

  tags = {
    usage = "terraform-state"
  }
}

resource "azurerm_storage_container" "iac" {
  name                  = "terraformstate"
  storage_account_name  = azurerm_storage_account.owl_iac_storage.name
  container_access_type = "private"
}

resource "azurerm_role_assignment" "storage_contrib" {
  scope                = azurerm_storage_account.owl_iac_storage.id
  role_definition_name = "Storage Blob Data Contributor"
  principal_id         = data.azurerm_client_config.current.object_id
}